import requests
import logging

logger = logging.getLogger(__name__)


def send_email(data, auth_key):
    if auth_key is None:
        logger.error('MALLGO_AUTH_KEY is not defined in settings.py')
        return False
    body = {
        "headers": {
            'Authorization': auth_key
        }, "body": {
            'from_email': data.from_email,
            'to_email': data.to,
            'cc_email': data.cc,
            'bcc_email': data.bcc,
            'subject': data.subject,
            'body': data.body,
        }
    }
    if data.template is not None:
        body['body']['template_id'] = data.template
        if data.template_vars is not None:
            body['body']['template_vars'] = data.template_vars
        else:
            body['body']['template_vars'] = {}
    url = 'https://api.email.mallgo.co/send-email/'
    headers = {
        'Content-Type': 'application/json',
    }
    response = requests.post(url, json=body, headers=headers)
    logger.debug(response.content)
    if response.status_code != 200:
        logger.error("MallGo could not send the email, endpoint response: %s" % response.content)
        return False
    # TODO Return the uuid of the email sent
    logger.debug("Email sent successfully %s" % response.content)
    return True



from typing import Any
from django.core.mail.backends.base import BaseEmailBackend
from MallGoEmail.send import send_email
from django.core.exceptions import ImproperlyConfigured


class MallGoEmailBackend(BaseEmailBackend):

    def __init__(self, fail_silently: bool = ..., **kwargs: Any) -> None:
        super(MallGoEmailBackend, self).__init__(fail_silently=fail_silently, **kwargs)
        try:
            from django.conf import settings
            self.auth_key = settings.MALLGO_AUTH_KEY
        except:
            raise ImproperlyConfigured('MALLGO_AUTH_KEY is not defined in settings.py')

    def send_messages(self, email_messages):
        for message in email_messages:
            mail = send_email(message, self.auth_key)
            if not mail:
                return False
        return True

    def send_message(self, email_message):
        return self.send_messages([email_message])
